"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = setup;

var _fs = _interopRequireDefault(require("fs"));

var _ejs = _interopRequireDefault(require("ejs"));

var _path = _interopRequireDefault(require("path"));

var _inquirer = _interopRequireDefault(require("inquirer"));

var _yarnInstall = _interopRequireDefault(require("yarn-install"));

var _config = require("./config");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function setup() {
  console.log(_config.CONFIG_HELPER_INTRO); // eslint-disable-line no-console

  _inquirer.default.prompt(_config.QUESTIONNAIRE).then(answers => {
    let packagesToInstall = [];

    if (answers.installRunner) {
      packagesToInstall.push(`@wdio/${answers.runner}-runner`);
    }

    if (answers.installFramework) {
      packagesToInstall.push(`@wdio/${answers.framework}-framework`);
    }

    if (answers.installReporter) {
      packagesToInstall = packagesToInstall.concat(answers.reporters);
    }

    if (answers.installServices) {
      packagesToInstall = packagesToInstall.concat(answers.services);
    }

    if (answers.executionMode === 'sync') {
      packagesToInstall.push('@wdio/sync');
    }

    if (packagesToInstall.length > 0) {
      console.log('\nInstalling wdio packages:\n-', packagesToInstall.join('\n- ')); // eslint-disable-line no-console

      const result = (0, _yarnInstall.default)({
        deps: packagesToInstall,
        dev: true
      });

      if (result.status != 0) {
        throw new Error(result.stderr);
      }

      console.log('\nPackages installed successfully, creating configuration file...'); // eslint-disable-line no-console
    }

    renderConfigurationFile(answers);
    process.exit(0);
  });
}

function renderConfigurationFile(answers) {
  let tpl = _fs.default.readFileSync(_path.default.join(__dirname, '/templates/wdio.conf.tpl.ejs'), 'utf8');

  let renderedTpl = _ejs.default.render(tpl, {
    answers
  });

  _fs.default.writeFileSync(_path.default.join(process.cwd(), 'wdio.conf.js'), renderedTpl);

  console.log(_config.CONFIG_HELPER_SUCCESS_MESSAGE); // eslint-disable-line no-console
}