"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runServiceHook = runServiceHook;
exports.filterPackageName = filterPackageName;
exports.getRunnerName = getRunnerName;

var _logger = _interopRequireDefault(require("@wdio/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _logger.default)('@wdio/cli:utils');
/**
 * run service launch sequences
 */

async function runServiceHook(launcher, hookName, ...args) {
  try {
    return await Promise.all(launcher.map(service => {
      if (typeof service[hookName] === 'function') {
        return service[hookName](...args);
      }
    }));
  } catch (e) {
    log.error(`A service failed in the '${hookName}' hook\n${e.stack}\n\nContinue...`);
  }
}
/**
 * map package names
 */


function filterPackageName(type) {
  return pkgLabels => pkgLabels.map(pkgLabel => pkgLabel.trim().includes('@wdio') ? `@wdio/${pkgLabel.split(/- /)[0].trim()}-${type}` : `wdio-${pkgLabel.split(/- /)[0].trim()}-${type}`);
}
/**
 * get runner identification by caps
 */


function getRunnerName(caps) {
  return caps.browserName || caps.appPackage || caps.appWaitActivity || caps.app || caps.platformName || 'undefined';
}