"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _util = require("util");

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _seleniumStandalone = _interopRequireDefault(require("selenium-standalone"));

var _getFilePath = _interopRequireDefault(require("./utils/getFilePath"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_LOG_FILENAME = 'selenium-standalone.txt';

class SeleniumStandaloneLauncher {
  constructor() {
    this.seleniumLogs = null;
    this.seleniumArgs = {};
    this.seleniumInstallArgs = {};
    return this;
  }

  async onPrepare(config) {
    this.seleniumArgs = config.seleniumArgs || {};
    this.seleniumInstallArgs = config.seleniumInstallArgs || {};
    this.seleniumLogs = config.seleniumLogs;
    this.skipSeleniumInstall = !!config.skipSeleniumInstall;

    if (!this.skipSeleniumInstall) {
      await (0, _util.promisify)(_seleniumStandalone.default.install)(this.seleniumInstallArgs);
    }

    this.process = await (0, _util.promisify)(_seleniumStandalone.default.start)(this.seleniumArgs);

    if (typeof this.seleniumLogs === 'string') {
      this._redirectLogStream();
    }
  }

  onComplete() {
    if (this.process) {
      this.process.kill();
    }
  }

  _redirectLogStream() {
    const logFile = (0, _getFilePath.default)(this.seleniumLogs, DEFAULT_LOG_FILENAME); // ensure file & directory exists

    _fsExtra.default.ensureFileSync(logFile);

    const logStream = _fsExtra.default.createWriteStream(logFile, {
      flags: 'w'
    });

    this.process.stdout.pipe(logStream);
    this.process.stderr.pipe(logStream);
  }

}

exports.default = SeleniumStandaloneLauncher;